/**
 * 	\file		serialTest.cpp
 *  \author:    Joshua J Bialkowski (jbialk@mit.edu)
 *  \date:      Oct 27, 2009
 *  \brief:
 *
 *  detail:
 *  This is a simple test program that demonstrates how to connect to and
 *  write commands to the arduino transmitter interface using windows.
 *
 *  the TxDuino is an interface into the futaba FP-TP-FM transmitter module,
 *  which accepts an RC PPM input. This signal contains a maximum of 8
 *  servo channels.
 */

#include <iostream>
#include <iomanip>
#include <cmath>

#include "CTxDuino.h"
#include "constants.h"

using namespace std;
using namespace txduino;

int main( int argc, char** argv )
{
    using std::cout;
    using std::endl;
    using std::sin;
    using std::setw;


    // check to ensure that the command line included a device to open
    if( argc < 2 )
    {
        cout << "Usage: serialTest.exe [Device Name]\n"
                "   where [Device Name] is the name of the COM port file on\n "
                "   windows (i.e. \\\\.\\COM8), or the name of the serial\n "
                "   device on *nix (i.e. /dev/tty8)\n" << endl;

        return -1;
    }

    // grab a pointer to the device to open
    char*       strDevName = argv[1];

    // create the txduino device
    CTxDuino tx(strDevName);

    // send a sinusoidal input on all channels (except for channel 3, which is
    // usually the throttle) for 10 seconds
    for(int i=0; i < 1000; i++)
    {
        for(int j=0; j < 8; j++)
            tx.setRaw(j, (unsigned char)
                            (125.0 + 75.0 * sin( 2.0 * PI * i / 100.0 )) );

        tx.setRaw(2, 0);

        for(int j=0; j < 8; j++)
            cout << setw(3) << (int)tx.getRaw(j) << " | ";
        cout << endl;

        tx.send();

#ifdef TXD_MIGNW
        Sleep(1);
#endif

#ifdef TXD_LINUX
        usleep(0.001);
#endif
    }


    return 0;
}







